function timeLine(dom) {
    this.container = dom
    this.chart = echarts.init(dom)
    this.isMock = true
    this.items = []
    this.aggregation = null
    this.options = {}
    this.render()
    this.addEvent();
}
timeLine.prototype.addEvent = function () {
    var that = this
    this.chart.on('click', function (params) {
        that.onSelectionChange(params.name)
    })
    this.chart.on('timelinechanged', function (params) {
        that.onSelectionChange(that.items[params.currentIndex])
    })
}

timeLine.prototype.onSelectionChange = function (selectedDatas) {
    try {
        var name = this.aggregation.dimensions[0];
    } catch (err) {
    }
    var value = selectedDatas;
    var filterSetting = new WebContent.Models.CrossFilterSetting([name]);
    filterSetting.filter(name, value)
    WebContent.doCrossFilter(filterSetting);
};

timeLine.prototype.render = function () {
    this.chart.clear()
    this.container.style.opacity = this.isMock ? 0.3 : 1
    var items = this.isMock ? timeLine.mockItems : this.items
    var options = this.options
    option = {
        timeline: {
            data: items,
            show: true,
            axisType: 'category',
            autoPlay: true,
            top: 'middle',
            left: '5%',
            right: '5%',
            playInterval: options.playInterval,
            symbolSize: options.symbolSize,
            lineStyle: {
                show: true,
                color: options.lineColor,
            },
            checkpointStyle: {
                color: options.checkpointColor,
                symbolSize: options.symbolSize,
                borderWidth: 5,
                borderColor: options.borderColor
            },
            label: {
                show: true,
                color: "white",
                fontSize: 14
            },
            controlStyle: {
                show: true,
                showPrevBtn: false,
                showNextBtn: false
            }
        }
    }
    this.chart.setOption(option)
}

timeLine.prototype.validate = function (aggregation) {
    return aggregation && aggregation.values.length > 0 && aggregation.dimensions.length > 0;
}

timeLine.prototype.update = function (aggregation, options) {
    this.options = this.parseOptions(options)
    if (!this.validate(aggregation)) {
        this.isMock = true
        this.render()
        return
    }
    this.isMock = false
    var datas = aggregation.data
    var dim = aggregation.dimensions[0]
    var arr = []
    datas.map(function (item) {
        arr.push(item[dim])
    })
    this.items = arr.sort(function (a, b) { return a - b })
    this.aggregation = aggregation
    this.render()
}

timeLine.prototype.parseOptions = function (options) {
    var opt = options || {}
    var obj = {}
    var defaultOptions = timeLine.defaultOptions

    for (var att in defaultOptions) {
        obj[att] = opt[att] === void 0 ? defaultOptions[att] : opt[att]
    }

    WebContent.syncOptions(obj)
    return obj
}

timeLine.prototype.resize = function () {
    this.chart.resize()
}

timeLine.mockItems = ["2014", "2015", "2016", "2017", "2018", "2019"]

timeLine.defaultOptions = {
    playInterval: 10000,
    symbolSize: 12,
    lineColor: '#009ce0',
    checkpointColor: '#0c797d',
    borderColor: 'rgba(104, 204, 202, 0.65)'
}

var dom = document.getElementById('root')
var myChart = new timeLine(dom)

//初始化web content
WebContent.init(function onUpdate(aggregation, options) {
    //当聚合数据变化时, 重新渲染chart
    myChart.update(aggregation, options)
})

//监听resize事件, 确保chart占满iframe
window.addEventListener('resize', function () {
    myChart.resize()
})